//  Copyright 2004 The Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package hivemind.test.rules;

import org.apache.hivemind.ApplicationRuntimeException;
import org.apache.hivemind.Registry;
import org.apache.hivemind.schema.Translator;
import org.apache.hivemind.schema.rules.SmartTranslator;
import org.apache.hivemind.test.HiveMindTestCase;

/**
 * Tests for {@link org.apache.hivemind.schema.rules.SmartTranslator}.
 *
 * @author Howard Lewis Ship
 */
public class TestSmartTranslator extends HiveMindTestCase
{
    /**
     * Test a primitive type (int).
     */
    public void testInt()
    {
        Translator t = new SmartTranslator();

        Object result = t.translate(null, int.class, "-37");

        assertEquals(new Integer(-37), result);
    }

    public void testBlankInput()
    {
        Translator t = new SmartTranslator();

        assertNull(t.translate(null, int.class, ""));
    }

    public void testDefault()
    {
        Translator t = new SmartTranslator("default=100");

        Object result = t.translate(null, int.class, "");

        assertEquals(new Integer(100), result);
    }

    /**
     * Test a wrapper type (Double).
     */
    public void testDouble()
    {
        Translator t = new SmartTranslator();

        Object result = t.translate(null, Double.class, "3.14");

        assertEquals(new Double("3.14"), result);
    }

    public void testNoEditor()
    {
        Translator t = new SmartTranslator();

        try
        {
            t.translate(null, Registry.class, "fred");

            unreachable();
        }
        catch (ApplicationRuntimeException ex)
        {
            assertEquals(
                "Unable to translate 'fred' to type org.apache.hivemind.Registry: "
                    + "No property editor for org.apache.hivemind.Registry.",
                ex.getMessage());
        }
    }
}
